@@ -182,7 +182,7 @@ def validate(attrs, **context):
             else:
                 cxt = DataContext.objects.get(id=attrs['id'])
         except DataContext.DoesNotExist:
-            raise ValidationError('DataContext "{0}" does not exist.'.format(attrs['id']))
+            raise ValidationError(u'DataContext "{0}" does not exist.'.format(attrs['id']))
         validate(cxt.json, **context)
     elif is_condition(attrs):
         from avocado.models import DataField
@@ -194,7 +194,7 @@ def validate(attrs, **context):
     elif is_branch(attrs):
         map(lambda x: validate(x), attrs['children'])
     else:
-        raise ValidationError('Object neither a branch nor condition: {0}'.format(attrs))
+        raise ValidationError(u'Object neither a branch nor condition: {0}'.format(attrs))
 
 
 def parse(attrs, **context):
